@@ -39,59 +39,72 @@
 
 namespace Py
 {
-bool _CFunction_Check( PyObject *op )   { return op->ob_type == _CFunction_Type(); }
-bool _Complex_Check( PyObject *op )     { return op->ob_type == _Complex_Type(); }
-bool _Dict_Check( PyObject *op )        { return op->ob_type == _Dict_Type(); }
-bool _Float_Check( PyObject *op )       { return op->ob_type == _Float_Type(); }
-bool _Function_Check( PyObject *op )    { return op->ob_type == _Function_Type(); }
-bool _Boolean_Check( PyObject *op )     { return op->ob_type == _Bool_Type(); }
-bool _List_Check( PyObject *op )        { return op->ob_type == _List_Type(); }
-bool _Long_Check( PyObject *op )        { return op->ob_type == _Long_Type(); }
-bool _Method_Check( PyObject *op )      { return op->ob_type == _Method_Type(); }
-bool _Module_Check( PyObject *op )      { return op->ob_type == _Module_Type(); }
-bool _Range_Check( PyObject *op )       { return op->ob_type == _Range_Type(); }
-bool _Slice_Check( PyObject *op )       { return op->ob_type == _Slice_Type(); }
-bool _TraceBack_Check( PyObject *op )   { return op->ob_type == _TraceBack_Type(); }
-bool _Tuple_Check( PyObject *op )       { return op->ob_type == _Tuple_Type(); }
-bool _Type_Check( PyObject *op )        { return op->ob_type == _Type_Type(); }
-bool _Unicode_Check( PyObject *op )     { return op->ob_type == _Unicode_Type(); }
+static int _IsInstance( PyObject *op, PyTypeObject *type )
+{
+    return PyObject_IsInstance( op, reinterpret_cast<PyObject *>( type ) );
+}
+
+bool _CFunction_Check( PyObject *op )   { return _IsInstance( op, _CFunction_Type() ) > 0; }
+bool _Complex_Check( PyObject *op )     { return _IsInstance( op, _Complex_Type() ) > 0; }
+bool _Dict_Check( PyObject *op )        { return _IsInstance( op, _Dict_Type() ) > 0; }
+bool _Float_Check( PyObject *op )       { return _IsInstance( op, _Float_Type() ) > 0; }
+#if PY_MAJOR_VERSION == 2 || !defined( Py_LIMITED_API )
+bool _Function_Check( PyObject *op )    { return _IsInstance( op, _Function_Type() ) > 0; }
+#endif
+bool _Boolean_Check( PyObject *op )     { return _IsInstance( op, _Bool_Type() ) > 0; }
+bool _List_Check( PyObject *op )        { return _IsInstance( op, _List_Type() ) > 0; }
+bool _Long_Check( PyObject *op )        { return _IsInstance( op, _Long_Type() ) > 0; }
+#if PY_MAJOR_VERSION == 2 || !defined( Py_LIMITED_API )
+bool _Method_Check( PyObject *op )      { return _IsInstance( op, _Method_Type() ) > 0; }
+#endif
+bool _Module_Check( PyObject *op )      { return _IsInstance( op, _Module_Type() ) > 0; }
+bool _Range_Check( PyObject *op )       { return _IsInstance( op, _Range_Type() ) > 0; }
+bool _Slice_Check( PyObject *op )       { return _IsInstance( op, _Slice_Type() ) > 0; }
+bool _TraceBack_Check( PyObject *op )   { return _IsInstance( op, _TraceBack_Type() ) > 0; }
+bool _Tuple_Check( PyObject *op )       { return _IsInstance( op, _Tuple_Type() ) > 0; }
+bool _Type_Check( PyObject *op )        { return _IsInstance( op, _Type_Type() ) > 0; }
+bool _Unicode_Check( PyObject *op )     { return _IsInstance( op, _Unicode_Type() ) > 0; }
 #if PY_MAJOR_VERSION == 2
-bool _String_Check( PyObject *op )      { return op->ob_type == _String_Type(); }
-bool _Int_Check( PyObject *op )         { return op->ob_type == _Int_Type(); }
-bool _CObject_Check( PyObject *op )     { return op->ob_type == _CObject_Type(); }
+bool _String_Check( PyObject *op )      { return _IsInstance( op, _String_Type() ) > 0; }
+bool _Int_Check( PyObject *op )         { return _IsInstance( op, _Int_Type() ) > 0; }
+bool _CObject_Check( PyObject *op )     { return _IsInstance( op, _CObject_Type() ) > 0; }
 #endif
 #if PY_MAJOR_VERSION >= 3
-bool _Bytes_Check( PyObject *op )       { return op->ob_type == _Bytes_Type(); }
+bool _Bytes_Check( PyObject *op )       { return _IsInstance( op, _Bytes_Type() ) > 0; }
 #endif
 
 #if defined(PY_WIN32_DELAYLOAD_PYTHON_DLL)
 
-#if defined(MS_WINDOWS)
-#include <windows.h>
+# if defined(MS_WINDOWS)
+#  include <windows.h>
 
 
 static HMODULE python_dll;
 
-#define PYCXX_STANDARD_EXCEPTION( eclass, bclass ) \
+#  define PYCXX_STANDARD_EXCEPTION( eclass, bclass ) \
     static PyObject *ptr_Exc_##eclass = NULL;
 
-#if PY_MAJOR_VERSION == 2
-#include "CXX/Python2/cxx_standard_exceptions.hxx"
-#else
-#include "CXX/Python3/cxx_standard_exceptions.hxx"
-#endif
+#  if PY_MAJOR_VERSION == 2
+#   include "CXX/Python2/cxx_standard_exceptions.hxx"
+#  else
+#   include "CXX/Python3/cxx_standard_exceptions.hxx"
+#  endif
 
-#undef PYCXX_STANDARD_EXCEPTION
+#  undef PYCXX_STANDARD_EXCEPTION
 
 static PyTypeObject *ptr__CFunction_Type = NULL;
 static PyTypeObject *ptr__Complex_Type = NULL;
 static PyTypeObject *ptr__Dict_Type = NULL;
 static PyTypeObject *ptr__Float_Type = NULL;
+#  if PY_MAJOR_VERSION == 2 || !defined( Py_LIMITED_API )
 static PyTypeObject *ptr__Function_Type = NULL;
+#  endif
 static PyTypeObject *ptr__Bool_Type = NULL;
 static PyTypeObject *ptr__List_Type = NULL;
 static PyTypeObject *ptr__Long_Type = NULL;
+#  if PY_MAJOR_VERSION == 2 || !defined( Py_LIMITED_API )
 static PyTypeObject *ptr__Method_Type = NULL;
+#  endif
 static PyTypeObject *ptr__Module_Type = NULL;
 static PyTypeObject *ptr__Range_Type = NULL;
 static PyTypeObject *ptr__Slice_Type = NULL;
@@ -99,26 +112,32 @@ static PyTypeObject *ptr__TraceBack_Type = NULL;
 static PyTypeObject *ptr__Tuple_Type = NULL;
 static PyTypeObject *ptr__Type_Type = NULL;
 static PyTypeObject *ptr__Unicode_Type = NULL;
-#if PY_MAJOR_VERSION == 2
+#  if PY_MAJOR_VERSION == 2
 static PyTypeObject *ptr__Int_Type = NULL;
 static PyTypeObject *ptr__String_Type = NULL;
 static PyTypeObject *ptr__CObject_Type = NULL;
-#endif
-#if PY_MAJOR_VERSION >= 3
+#  endif
+#  if PY_MAJOR_VERSION >= 3
 static PyTypeObject *ptr__Bytes_Type = NULL;
-#endif
+#  endif
 
+#  if PY_MAJOR_VERSION == 2 || !defined( Py_LIMITED_API )
 static int *ptr_Py_DebugFlag = NULL;
 static int *ptr_Py_InteractiveFlag = NULL;
 static int *ptr_Py_OptimizeFlag = NULL;
 static int *ptr_Py_NoSiteFlag = NULL;
 static int *ptr_Py_VerboseFlag = NULL;
 
+#   if PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION >= 7
+static const char **ptr__Py_PackageContext = NULL;
+#   else
 static char **ptr__Py_PackageContext = NULL;
+#   endif
+#  endif
 
-#ifdef Py_REF_DEBUG
+#  ifdef Py_REF_DEBUG
 int *ptr_Py_RefTotal;
-#endif
+#  endif
 
 
 //--------------------------------------------------------------------------------
@@ -188,13 +207,24 @@ static char **GetCharPointer_as_CharPointerPointer( const char *name )
     return (char **)addr;
 }
 
+#if PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION >= 7
+static char **GetConstCharPointer_as_ConstCharPointerPointer( const char *name )
+{
+    FARPROC addr = GetProcAddress( python_dll, name );
+    if( addr == NULL )
+        throw GetAddressException( name );
 
-#ifdef _DEBUG
-static const char python_dll_name_format[] = "PYTHON%1.1d%1.1d_D.DLL";
-#else
-static const char python_dll_name_format[] = "PYTHON%1.1d%1.1d.DLL";
+    return (const char **)addr;
+}
 #endif
 
+
+#  ifdef _DEBUG
+static const char python_dll_name_format[] = "PYTHON%1.1d%1.1d_D.DLL";
+#  else
+static const char python_dll_name_format[] = "PYTHON%1.1d%1.1d.DLL";
+#  endif
+
 //--------------------------------------------------------------------------------
 bool InitialisePythonIndirectInterface()
 {
@@ -208,45 +238,56 @@ bool InitialisePythonIndirectInterface()
 
     try
     {
-#ifdef Py_REF_DEBUG
+#  ifdef Py_REF_DEBUG
     ptr_Py_RefTotal             = GetInt_as_IntPointer( "_Py_RefTotal" );
-#endif
+#  endif
+#  if PY_MAJOR_VERSION == 2 || !defined( Py_LIMITED_API )
     ptr_Py_DebugFlag            = GetInt_as_IntPointer( "Py_DebugFlag" );
     ptr_Py_InteractiveFlag      = GetInt_as_IntPointer( "Py_InteractiveFlag" );
     ptr_Py_OptimizeFlag         = GetInt_as_IntPointer( "Py_OptimizeFlag" );
     ptr_Py_NoSiteFlag           = GetInt_as_IntPointer( "Py_NoSiteFlag" );
     ptr_Py_VerboseFlag          = GetInt_as_IntPointer( "Py_VerboseFlag" );
-    ptr__Py_PackageContext      = GetCharPointer_as_CharPointerPointer( "_Py_PackageContext" );
 
-#define PYCXX_STANDARD_EXCEPTION( eclass, bclass )
+#    if PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION >= 7
+    ptr__Py_PackageContext      = GetConstCharPointer_as_ConstCharPointerPointer( "_Py_PackageContext" );
+#    else
+    ptr__Py_PackageContext      = GetCharPointer_as_CharPointerPointer( "_Py_PackageContext" );
+#    endif
+#  endif
+
+#  define PYCXX_STANDARD_EXCEPTION( eclass, bclass )
     ptr_Exc_#eclass = GetPyTypeObject_As_PyTypeObjectPointer( "PyExc_" #eclass );
 
-#if PY_MAJOR_VERSION == 2
-#include "CXX/Python2/cxx_standard_exceptions.hxx"
-#else
-#include "CXX/Python3/cxx_standard_exceptions.hxx"
-#endif
+#  if PY_MAJOR_VERSION == 2
+#   include "CXX/Python2/cxx_standard_exceptions.hxx"
+#  else
+#   include "CXX/Python3/cxx_standard_exceptions.hxx"
+#  endif
 
-#undef PYCXX_STANDARD_EXCEPTION
+#  undef PYCXX_STANDARD_EXCEPTION
 
     ptr__PyNone                 = GetPyObject_As_PyObjectPointer( "_Py_NoneStruct" );
 
-#if PY_MAJOR_VERSION == 2
+#  if PY_MAJOR_VERSION == 2
     ptr__PyFalse                = GetPyObject_As_PyObjectPointer( "_Py_ZeroStruct" );
-#else
+#  else
     ptr__PyFalse                = GetPyObject_As_PyObjectPointer( "_Py_FalseStruct" );
-#endif
+#  endif
     ptr__PyTrue                 = GetPyObject_As_PyObjectPointer( "_Py_TrueStruct" );
 
     ptr__CFunction_Type         = GetPyTypeObject_As_PyTypeObjectPointer( "PyCFunction_Type" );
     ptr__Complex_Type           = GetPyTypeObject_As_PyTypeObjectPointer( "PyComplex_Type" );
     ptr__Dict_Type              = GetPyTypeObject_As_PyTypeObjectPointer( "PyDict_Type" );
     ptr__Float_Type             = GetPyTypeObject_As_PyTypeObjectPointer( "PyFloat_Type" );
+#  if PY_MAJOR_VERSION == 2 || !defined( Py_LIMITED_API )
     ptr__Function_Type          = GetPyTypeObject_As_PyTypeObjectPointer( "PyFunction_Type" );
+#  endif
     ptr__Bool_Type              = GetPyTypeObject_As_PyTypeObjectPointer( "PyBool_Type" );
     ptr__List_Type              = GetPyTypeObject_As_PyTypeObjectPointer( "PyList_Type" );
     ptr__Long_Type              = GetPyTypeObject_As_PyTypeObjectPointer( "PyLong_Type" );
+#  if PY_MAJOR_VERSION == 2 || !defined( Py_LIMITED_API )
     ptr__Method_Type            = GetPyTypeObject_As_PyTypeObjectPointer( "PyMethod_Type" );
+#  endif
     ptr__Module_Type            = GetPyTypeObject_As_PyTypeObjectPointer( "PyModule_Type" );
     ptr__Range_Type             = GetPyTypeObject_As_PyTypeObjectPointer( "PyRange_Type" );
     ptr__Slice_Type             = GetPyTypeObject_As_PyTypeObjectPointer( "PySlice_Type" );
@@ -254,14 +295,14 @@ bool InitialisePythonIndirectInterface()
     ptr__Tuple_Type             = GetPyTypeObject_As_PyTypeObjectPointer( "PyTuple_Type" );
     ptr__Type_Type              = GetPyTypeObject_As_PyTypeObjectPointer( "PyType_Type" );
     ptr__Unicode_Type           = GetPyTypeObject_As_PyTypeObjectPointer( "PyUnicode_Type" );
-#if PY_MAJOR_VERSION == 2
+#  if PY_MAJOR_VERSION == 2
     ptr__String_Type            = GetPyTypeObject_As_PyTypeObjectPointer( "PyString_Type" );
     ptr__Int_Type               = GetPyTypeObject_As_PyTypeObjectPointer( "PyInt_Type" );
     ptr__CObject_Type           = GetPyTypeObject_As_PyTypeObjectPointer( "PyCObject_Type" );
-#endif
-#if PY_MAJOR_VERSION >= 3
+#  endif
+#  if PY_MAJOR_VERSION >= 3
     ptr__Bytes_Type             = GetPyTypeObject_As_PyTypeObjectPointer( "PyBytes_Type" );
-#endif
+#  endif
     }
     catch( GetAddressException &e )
     {
@@ -298,17 +339,17 @@ PyObject *_Exc_NotImplementedError()    { return ptr__Exc_NotImplementedError; }
 PyObject *_Exc_OSError()                { return ptr__Exc_OSError; }
 PyObject *_Exc_OverflowError()          { return ptr__Exc_OverflowError; }
 PyObject *_Exc_RuntimeError()           { return ptr__Exc_RuntimeError; }
-#if PY_MAJOR_VERSION == 2
+#  if PY_MAJOR_VERSION == 2
 PyObject *_Exc_StandardError()          { return ptr__Exc_StandardError; }
-#endif
+#  endif
 PyObject *_Exc_SyntaxError()            { return ptr__Exc_SyntaxError; }
 PyObject *_Exc_SystemError()            { return ptr__Exc_SystemError; }
 PyObject *_Exc_SystemExit()             { return ptr__Exc_SystemExit; }
 PyObject *_Exc_TypeError()              { return ptr__Exc_TypeError; }
 PyObject *_Exc_ValueError()             { return ptr__Exc_ValueError; }
-#ifdef MS_WINDOWS
+#  ifdef MS_WINDOWS
 PyObject *_Exc_WindowsError()           { return ptr__Exc_WindowsError; }
-#endif
+#  endif
 PyObject *_Exc_ZeroDivisionError()      { return ptr__Exc_ZeroDivisionError; }
 PyObject *_Exc_IndentationError()       { return ptr__Exc_IndentationError; }
 PyObject *_Exc_TabError()               { return ptr__Exc_TabError; }
@@ -327,11 +368,15 @@ PyTypeObject *_CFunction_Type()         { return ptr__CFunction_Type; }
 PyTypeObject *_Complex_Type()           { return ptr__Complex_Type; }
 PyTypeObject *_Dict_Type()              { return ptr__Dict_Type; }
 PyTypeObject *_Float_Type()             { return ptr__Float_Type; }
+#  if PY_MAJOR_VERSION == 2 || !defined( Py_LIMITED_API )
 PyTypeObject *_Function_Type()          { return ptr__Function_Type; }
+#  endif
 PyTypeObject *_Bool_Type()              { return ptr__Bool_Type; }
 PyTypeObject *_List_Type()              { return ptr__List_Type; }
 PyTypeObject *_Long_Type()              { return ptr__Long_Type; }
+#  if PY_MAJOR_VERSION == 2 || !defined( Py_LIMITED_API )
 PyTypeObject *_Method_Type()            { return ptr__Method_Type; }
+#  endif
 PyTypeObject *_Module_Type()            { return ptr__Module_Type; }
 PyTypeObject *_Range_Type()             { return ptr__Range_Type; }
 PyTypeObject *_Slice_Type()             { return ptr__Slice_Type; }
@@ -339,39 +384,44 @@ PyTypeObject *_TraceBack_Type()         { return ptr__TraceBack_Type; }
 PyTypeObject *_Tuple_Type()             { return ptr__Tuple_Type; }
 PyTypeObject *_Type_Type()              { return ptr__Type_Type; }
 PyTypeObject *_Unicode_Type()           { return ptr__Unicode_Type; }
-#if PY_MAJOR_VERSION == 2
+#  if PY_MAJOR_VERSION == 2
 PyTypeObject *_String_Type()            { return ptr__String_Type; }
 PyTypeObject *_Int_Type()               { return ptr__Int_Type; }
 PyTypeObject *_CObject_Type()           { return ptr__CObject_Type; }
-#endif
-#if PY_MAJOR_VERSION >= 3
+#  endif
+#  if PY_MAJOR_VERSION >= 3
 PyTypeObject *_Bytes_Type()             { return ptr__Bytes_Type; }
-#endif
-
-char *__Py_PackageContext()             { return *ptr__Py_PackageContext; }
-
+#  endif
 
 //
 //    wrap the Python Flag variables
 //
+#  if PY_MAJOR_VERSION == 2 || !defined( Py_LIMITED_API )
 int &_Py_DebugFlag()                    { return *ptr_Py_DebugFlag; }
 int &_Py_InteractiveFlag()              { return *ptr_Py_InteractiveFlag; }
 int &_Py_OptimizeFlag()                 { return *ptr_Py_OptimizeFlag; }
 int &_Py_NoSiteFlag()                   { return *ptr_Py_NoSiteFlag; }
 int &_Py_VerboseFlag()                  { return *ptr_Py_VerboseFlag; }
+#  endif
 
-#if 0
-#define Py_INCREF(op) (                         \
+#  if PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION >= 7
+const char *__Py_PackageContext()       { return *ptr__Py_PackageContext; }
+#  else
+char *__Py_PackageContext()             { return *ptr__Py_PackageContext; }
+#  endif
+
+#  if 0
+#   define Py_INCREF(op) (                         \
     _Py_INC_REFTOTAL  _Py_REF_DEBUG_COMMA       \
     ((PyObject*)(op))->ob_refcnt++)
 
-#define Py_DECREF(op)                           \
+#   define Py_DECREF(op)                           \
     if (_Py_DEC_REFTOTAL  _Py_REF_DEBUG_COMMA   \
         --((PyObject*)(op))->ob_refcnt != 0)    \
         _Py_CHECK_REFCNT(op)                    \
     else                                        \
         _Py_Dealloc((PyObject *)(op))
-#endif
+#  endif
 
 void _XINCREF( PyObject *op )
 {
@@ -379,9 +429,9 @@ void _XINCREF( PyObject *op )
     if( op == NULL )
         return;
 
-#ifdef Py_REF_DEBUG
+#  ifdef Py_REF_DEBUG
     (*ptr_Py_RefTotal)++;
-#endif
+#  endif
     (op)->ob_refcnt++;
 
 }
@@ -392,18 +442,18 @@ void _XDECREF( PyObject *op )
     if( op == NULL )
         return;
 
-#ifdef Py_REF_DEBUG
+#  ifdef Py_REF_DEBUG
     (*ptr_Py_RefTotal)--;
-#endif
+#  endif
 
     if (--(op)->ob_refcnt == 0)
         _Py_Dealloc((PyObject *)(op));
 }
 
 
-#else
-#error "Can only delay load under Win32"
-#endif
+# else
+#  error "Can only delay load under Win32"
+# endif
 
 #else
 
@@ -416,16 +466,16 @@ void _XDECREF( PyObject *op )
 //
 //    Wrap variables as function calls
 //
-#define PYCXX_STANDARD_EXCEPTION( eclass, bclass ) \
+# define PYCXX_STANDARD_EXCEPTION( eclass, bclass ) \
     PyObject *_Exc_##eclass() { return ::PyExc_##eclass; }
 
-#if PY_MAJOR_VERSION == 2
-#include "CXX/Python2/cxx_standard_exceptions.hxx"
-#else
-#include "CXX/Python3/cxx_standard_exceptions.hxx"
-#endif
+# if PY_MAJOR_VERSION == 2
+#  include "CXX/Python2/cxx_standard_exceptions.hxx"
+# else
+#  include "CXX/Python3/cxx_standard_exceptions.hxx"
+# endif
 
-#undef PYCXX_STANDARD_EXCEPTION
+# undef PYCXX_STANDARD_EXCEPTION
 
 //
 //    wrap items in Object.h
@@ -439,11 +489,15 @@ PyTypeObject *_CFunction_Type()         { return &PyCFunction_Type; }
 PyTypeObject *_Complex_Type()           { return &PyComplex_Type; }
 PyTypeObject *_Dict_Type()              { return &PyDict_Type; }
 PyTypeObject *_Float_Type()             { return &PyFloat_Type; }
+# if PY_MAJOR_VERSION == 2 || !defined( Py_LIMITED_API )
 PyTypeObject *_Function_Type()          { return &PyFunction_Type; }
+# endif
 PyTypeObject *_Bool_Type()              { return &PyBool_Type; }
 PyTypeObject *_List_Type()              { return &PyList_Type; }
 PyTypeObject *_Long_Type()              { return &PyLong_Type; }
+# if PY_MAJOR_VERSION == 2 || !defined( Py_LIMITED_API )
 PyTypeObject *_Method_Type()            { return &PyMethod_Type; }
+# endif
 PyTypeObject *_Module_Type()            { return &PyModule_Type; }
 PyTypeObject *_Range_Type()             { return &PyRange_Type; }
 PyTypeObject *_Slice_Type()             { return &PySlice_Type; }
@@ -451,24 +505,30 @@ PyTypeObject *_TraceBack_Type()         { return &PyTraceBack_Type; }
 PyTypeObject *_Tuple_Type()             { return &PyTuple_Type; }
 PyTypeObject *_Type_Type()              { return &PyType_Type; }
 PyTypeObject *_Unicode_Type()           { return &PyUnicode_Type; }
-#if PY_MAJOR_VERSION == 2
+# if PY_MAJOR_VERSION == 2
 PyTypeObject *_String_Type()            { return &PyString_Type; }
 PyTypeObject *_Int_Type()               { return &PyInt_Type; }
 PyTypeObject *_CObject_Type()           { return &PyCObject_Type; }
-#endif
-#if PY_MAJOR_VERSION >= 3
+# endif
+# if PY_MAJOR_VERSION >= 3
 PyTypeObject *_Bytes_Type()             { return &PyBytes_Type; }
-#endif
+# endif
 
 //
 //    wrap flags
 //
+# if PY_MAJOR_VERSION == 2 || !defined( Py_LIMITED_API )
 int &_Py_DebugFlag()                    { return Py_DebugFlag; }
 int &_Py_InteractiveFlag()              { return Py_InteractiveFlag; }
 int &_Py_OptimizeFlag()                 { return Py_OptimizeFlag; }
 int &_Py_NoSiteFlag()                   { return Py_NoSiteFlag; }
 int &_Py_VerboseFlag()                  { return Py_VerboseFlag; }
+#  if PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION >= 7
+const char *__Py_PackageContext()       { return _Py_PackageContext; }
+#  else
 char *__Py_PackageContext()             { return _Py_PackageContext; }
+#  endif
+# endif
 
 //
 //    Needed to keep the abstactions for delayload interface
