@@ -18,12 +18,14 @@ class Setup:
     def __init__( self, argv ):
         args = argv[1:]
         if len(args) < 2:
-            raise ValueError( 'Usage: setup.py win32|win64|macosx|linux> <makefile>' )
+            raise ValueError( 'Usage: setup_makefile.py win32|win64|macosx|linux> <makefile>' )
 
         self.opt_debug = False
         self.opt_pycxx_debug = False
         self.opt_limited_api = None
 
+        self.is_pypy = hasattr( sys, 'pypy_version_info' )
+
         self.platform = args[0]
         del args[0]
 
@@ -429,10 +431,16 @@ class MacOsxCompilerGCC(CompilerGCC):
         self._addVar( 'PYTHON_VERSION', '%d.%d' % (sys.version_info[0], sys.version_info[1]) )
 
         self._addVar( 'PYTHONDIR',      sys.exec_prefix )
-        self._addVar( 'PYTHON_FRAMEWORK', '%(PYTHONDIR)s/Python' )
 
         self._addVar( 'PYTHON',         sys.executable )
-        self._addVar( 'PYTHON_INCLUDE', '%(PYTHONDIR)s/Headers' )
+
+        if self.setup.is_pypy:
+            self._addVar( 'PYTHON_INCLUDE', '%(PYTHONDIR)s/include' )
+            self._addVar( 'PYTHON_FRAMEWORK', '%(PYTHONDIR)s/bin/libpypy-c.dylib' )
+
+        else:
+            self._addVar( 'PYTHON_INCLUDE', '%(PYTHONDIR)s/Headers' )
+            self._addVar( 'PYTHON_FRAMEWORK', '%(PYTHONDIR)s/Python' )
 
         self._addVar( 'DEMO_DIR',       'Demo/Python%d' % (sys.version_info[0],) )
 
