@@ -5,7 +5,7 @@ import os
 
 print( 'Info: setup vesion info' )
 import sys
-sys.path.insert( 0, '../../Source')
+sys.path.insert( 0, os.path.abspath( '../../Source' ) )
 import pysvn
 import time
 import glob
