@@ -44,6 +44,12 @@ Py::Object pysvn_client::cmd_merge( const Py::Tuple &a_args, const Py::Dict &a_k
 #if defined( PYSVN_HAS_CLIENT_MERGE3 )
     { false, name_depth },
     { false, name_record_only },
+#endif
+#if defined( PYSVN_HAS_CLIENT_MERGE4 )
+    { false, name_allow_mixed_revisions },
+#endif
+#if defined( PYSVN_HAS_CLIENT_MERGE5 )
+    { false, name_ignore_mergeinfo },
 #endif
     { false, NULL }
     };
@@ -66,6 +72,13 @@ Py::Object pysvn_client::cmd_merge( const Py::Tuple &a_args, const Py::Dict &a_k
     bool notice_ancestry = args.getBoolean( name_notice_ancestry, false );
     bool dry_run = args.getBoolean( name_dry_run, false );
 
+#if defined( PYSVN_HAS_CLIENT_MERGE4 )
+    bool allow_mixed_revisions = args.getBoolean( name_allow_mixed_revisions, false );
+#endif
+#if defined( PYSVN_HAS_CLIENT_MERGE5 )
+    bool ignore_mergeinfo = args.getBoolean( name_ignore_mergeinfo, !notice_ancestry );
+#endif
+
 #if defined( PYSVN_HAS_CLIENT_MERGE2 )
     Py::List merge_options_list;
     if( args.hasArg( name_merge_options ) )
@@ -105,7 +118,44 @@ Py::Object pysvn_client::cmd_merge( const Py::Tuple &a_args, const Py::Dict &a_k
 
         PythonAllowThreads permission( m_context );
 
-#if defined( PYSVN_HAS_CLIENT_MERGE3 )
+#if defined( PYSVN_HAS_CLIENT_MERGE5 )
+        svn_error_t *error = svn_client_merge5
+            (
+            norm_path1.c_str(),
+            &revision1,
+            norm_path2.c_str(),
+            &revision2,
+            norm_local_path.c_str(),
+            depth,
+            ignore_mergeinfo,
+            !notice_ancestry,
+            force,      // force_delete
+            record_only,
+            dry_run,
+            allow_mixed_revisions,
+            merge_options,
+            m_context,
+            pool
+            );
+#elif defined( PYSVN_HAS_CLIENT_MERGE4 )
+        svn_error_t *error = svn_client_merge4
+            (
+            norm_path1.c_str(),
+            &revision1,
+            norm_path2.c_str(),
+            &revision2,
+            norm_local_path.c_str(),
+            depth,
+            !notice_ancestry,
+            force,
+            record_only,
+            dry_run,
+            allow_mixed_revisions,
+            merge_options,
+            m_context,
+            pool
+            );
+#elif defined( PYSVN_HAS_CLIENT_MERGE3 )
         svn_error_t *error = svn_client_merge3
             (
             norm_path1.c_str(),
@@ -184,6 +234,12 @@ Py::Object pysvn_client::cmd_merge_peg2( const Py::Tuple &a_args, const Py::Dict
     { false, name_record_only },
     { false, name_dry_run },
     { false, name_merge_options },
+#if defined( PYSVN_HAS_CLIENT_MERGE_PEG4 )
+    { false, name_allow_mixed_revisions },
+#endif
+#if defined( PYSVN_HAS_CLIENT_MERGE_PEG4 )
+    { false, name_ignore_mergeinfo },
+#endif
     { false, NULL }
     };
     FunctionArguments args( "merge_peg2", args_desc, a_args, a_kws );
@@ -197,6 +253,12 @@ Py::Object pysvn_client::cmd_merge_peg2( const Py::Tuple &a_args, const Py::Dict
     bool record_only = args.getBoolean( name_record_only, true );
     bool notice_ancestry = args.getBoolean( name_notice_ancestry, false );
     bool dry_run = args.getBoolean( name_dry_run, false );
+#if defined( PYSVN_HAS_CLIENT_MERGE4 )
+    bool allow_mixed_revisions = args.getBoolean( name_allow_mixed_revisions, false );
+#endif
+#if defined( PYSVN_HAS_CLIENT_MERGE5 )
+    bool ignore_mergeinfo = args.getBoolean( name_ignore_mergeinfo, false );
+#endif
 
     Py::List merge_options_list;
     if( args.hasArg( name_merge_options ) )
@@ -288,6 +350,42 @@ Py::Object pysvn_client::cmd_merge_peg2( const Py::Tuple &a_args, const Py::Dict
 
         PythonAllowThreads permission( m_context );
 
+#if defined( PYSVN_HAS_CLIENT_MERGE_PEG5 )
+        svn_error_t *error = svn_client_merge_peg5
+            (
+            norm_sources.c_str(),
+            ranges_to_merge,
+            &peg_revision,
+            norm_target_wcpath.c_str(),
+            depth,
+            ignore_mergeinfo,
+            !notice_ancestry,   // diff_ignore_ancestry
+            force,              // force_delete
+            record_only,
+            dry_run,
+            allow_mixed_revisions,
+            merge_options,
+            m_context,
+            pool
+            );
+#elif defined( PYSVN_HAS_CLIENT_MERGE_PEG4 )
+        svn_error_t *error = svn_client_merge_peg4
+            (
+            norm_sources.c_str(),
+            ranges_to_merge,
+            &peg_revision,
+            norm_target_wcpath.c_str(),
+            depth,
+            !notice_ancestry,
+            force,      // force_delete
+            record_only,
+            dry_run,
+            allow_mixed_revisions,
+            merge_options,
+            m_context,
+            pool
+            );
+#else
         svn_error_t *error = svn_client_merge_peg3
             (
             norm_sources.c_str(),
@@ -303,6 +401,7 @@ Py::Object pysvn_client::cmd_merge_peg2( const Py::Tuple &a_args, const Py::Dict
             m_context,
             pool
             );
+#endif
         permission.allowThisThread();
         if( error != 0 )
             throw SvnException( error );
@@ -395,7 +494,7 @@ Py::Object pysvn_client::cmd_merge_peg( const Py::Tuple &a_args, const Py::Dict
         PythonAllowThreads permission( m_context );
 
 #if defined( PYSVN_HAS_CLIENT_MERGE_PEG2 )
-        svn_error_t *error = svn_client_merge_peg2
+        svn_error_t *error = svn_client_merge_peg2 // ignore deprecation warning - support old Client().merge_peg()
             (
             norm_path.c_str(),
             &revision1,
@@ -498,7 +597,7 @@ Py::Object pysvn_client::cmd_merge_reintegrate( const Py::Tuple &a_args, const P
 
         PythonAllowThreads permission( m_context );
 
-        svn_error_t *error = svn_client_merge_reintegrate
+        svn_error_t *error = svn_client_merge_reintegrate // ignore deprecation warning - support old Client().merge_reintegrate()
             (
             norm_path.c_str(),
             &revision,
