@@ -34,16 +34,50 @@ std::string svnNormalisedIfPath( const std::string &unnormalised, SvnPool &pool
 {
     if( is_svn_url( unnormalised ) )
     {
-        const char *normalised_path = svn_path_canonicalize( unnormalised.c_str(), pool );
-        return std::string( normalised_path );
+        return svnNormalisedUrl( unnormalised, pool );
     }
     else
     {
-        const char *normalised_path = svn_path_internal_style( unnormalised.c_str(), pool );
-        return std::string( normalised_path );
+        return svnNormalisedPath( unnormalised, pool );
     }
 }
 
+
+#if defined(PYSVN_HAS_SVN_1_7)
+std::string svnNormalisedUrl( const std::string &unnormalised, SvnPool &pool )
+{
+    const char *normalised_path = svn_uri_canonicalize( unnormalised.c_str(), pool );
+    return std::string( normalised_path );
+}
+
+std::string svnNormalisedPath( const std::string &unnormalised, SvnPool &pool )
+{
+    const char *normalised_path = svn_dirent_internal_style( unnormalised.c_str(), pool );
+    return std::string( normalised_path );
+}
+
+
+// convert a path to what the native OS likes
+std::string osNormalisedPath( const std::string &unnormalised, SvnPool &pool )
+{
+    const char *local_path = svn_dirent_local_style( unnormalised.c_str(), pool );
+
+    return std::string( local_path );
+}
+
+#else
+std::string svnNormalisedUrl( const std::string &unnormalised, SvnPool &pool )
+{
+    const char *normalised_path = svn_path_canonicalize( unnormalised.c_str(), pool );
+    return std::string( normalised_path );
+}
+
+std::string svnNormalisedPath( const std::string &unnormalised, SvnPool &pool )
+{
+    const char *normalised_path = svn_path_internal_style( unnormalised.c_str(), pool );
+    return std::string( normalised_path );
+}
+
 // convert a path to what the native OS likes
 std::string osNormalisedPath( const std::string &unnormalised, SvnPool &pool )
 {
@@ -51,3 +85,4 @@ std::string osNormalisedPath( const std::string &unnormalised, SvnPool &pool )
 
     return std::string( local_path );
 }
+#endif
