@@ -841,15 +841,6 @@ class Win32CompilerMSVC90(Compiler):
                     #r'%(APR_LIB)s\xml.lib',
                     r'%(APR_LIB)s\libapr-1.lib',
                     ]
-        if False:
-            if os.path.exists( self.expand( r'%(SVN_LIB)s\serf\serf-1.lib' ) ):
-                ldlibs.append( r'%(SVN_LIB)s\serf\serf-1.lib' )
-
-            elif os.path.exists( self.expand( r'%(SVN_LIB)s\libsvn_ra_neon-1.lib' ) ):
-                ldlibs.append( r'%(SVN_LIB)s\libsvn_ra_neon-1.lib' )
-
-            else:
-                raise SetupError( 'Cannot find serf or neon' )
 
         ldlibs.append( r'ws2_32.lib' )
 
@@ -875,7 +866,7 @@ class Win32CompilerMSVC90(Compiler):
         rules.append( 'test-%(TN)s.win32.new.log: test-%(TN)s.cmd test-%(TN)s.win32.known_good-%(KGV)s.log' % v )
         rules.append( '	' r'-subst b: /d >nul 2>&1' % v )
         rules.append( '	' r'if exist testroot-%(TN)s rmdir /s /q testroot-%(TN)s' % v )
-        rules.append( '	' r'set PATH=%%(SVN_BIN)s;$(PATH)' % v )
+        rules.append( '	' r'set SVN_BIN=%%(SVN_BIN)s' % v )
         rules.append( '	' r'set PYTHON=%%(PYTHON)s' % v )
         rules.append( '	' r'test-%(TN)s.cmd >test-%(TN)s.win32.new.log 2>&1' % v )
         rules.append( '' )
@@ -900,8 +891,11 @@ class CompilerGCC(Compiler):
     def __init__( self, setup ):
         Compiler.__init__( self, setup )
 
-        self._addVar( 'CCC',            'g++' )
-        self._addVar( 'CC',             'gcc' )
+        self._addVar( 'CC',             os.environ.get('CC', 'gcc') )
+        self._addVar( 'CCC',            os.environ.get('CCC', 'g++') )
+
+        print( self.expand( 'Info: Using C compiler %(CC)s' ) )
+        print( self.expand( 'Info: Using C++ compiler %(CCC)s' ) )
 
     def getPythonExtensionFileExt( self ):
         return '.so'
@@ -1043,8 +1037,8 @@ class MacOsxCompilerGCC(CompilerGCC):
         else:
             arch_options = ''
 
-        self._addVar( 'CCC',            'g++ %s' % (arch_options,) )
-        self._addVar( 'CC',             'gcc %s' % (arch_options,) )
+        self._addVar( 'CCC',            'g++ %s -mmacosx-version-min=%s' % (arch_options, self.macosx_deployment_target) )
+        self._addVar( 'CC',             'gcc %s -mmacosx-version-min=%s' % (arch_options, self.macosx_deployment_target) )
 
         self._find_paths_pycxx_dir = [
                         '../Import/pycxx-%d.%d.%d' % min_pycxx_version,
@@ -1145,10 +1139,6 @@ class MacOsxCompilerGCC(CompilerGCC):
                     '-D%(DEBUG)s',
                     ]
 
-        if False and self.pycxx_version >= (7, 0, 0):
-            # PYSVN uses PYCXX in backward compat mode
-            py_cflags_list.append( r'-DPYCXX_6_2_COMPATIBILITY=1' )
-
         for define, value in self.py_module_defines:
             py_cflags_list.append( '-D%s=%s' % (define, value) )
 
@@ -1267,6 +1257,8 @@ class UnixCompilerGCC(CompilerGCC):
         self._addVar( 'PYTHON_INC',     distutils.sysconfig.get_python_inc( False ) )
         self._addVar( 'PYTHON_ARCH_SPECIFIC_INC',     distutils.sysconfig.get_python_inc( True ) )
 
+        py_ldflags_list = []
+
         py_cflags_list = [
                     '-Wall -fPIC',
                     '-I. -I%(APR_INC)s -I%(APU_INC)s -I%(SVN_INC)s',
@@ -1274,7 +1266,6 @@ class UnixCompilerGCC(CompilerGCC):
                     '-I%(PYTHON_ARCH_SPECIFIC_INC)s',
                     '-D%(DEBUG)s',
                     ]
-
         if self.pycxx_version >= (7, 0, 0):
             # PYSVN uses PYCXX in backward compat mode
             py_cflags_list.append( r'-DPYCXX_6_2_COMPATIBILITY=1' )
@@ -1287,15 +1278,24 @@ class UnixCompilerGCC(CompilerGCC):
         if self.options.hasOption( '--enable-debug' ):
             print( 'Info: Debug enabled' )
             py_cflags_list.append( '-g' )
+            py_ldflags_list.append( '-g' )
 
         if self.options.hasOption( '--disable-deprecated-functions-warnings' ):
             print( 'Info: Disable deprecated functions warnings' )
             py_cflags_list.append( '-Wno-deprecated-declarations' )
 
+        if 'CFLAGS' in os.environ:
+            py_cflags_list.append( os.environ['CFLAGS'] )
+
+        if 'LDFLAGS' in os.environ:
+            py_ldflags_list.append( os.environ['LDFLAGS'] )
+
+        self._addVar( 'LDFLAGS',   ' '.join( py_ldflags_list ) )
+
         self._addVar( 'CCFLAGS',    ' '.join( py_cflags_list ) )
         self._addVar( 'CCCFLAGS',   ' '.join( py_cflags_list+['-fexceptions -frtti'] ) )
         self._addVar( 'LDLIBS',     ' '.join( self._getLdLibs() ) )
-        self._addVar( 'LDSHARED',   '%(CCC)s -shared -g' )
+        self._addVar( 'LDSHARED',   '%(CCC)s -shared %(LDFLAGS)s' )
 
 #--------------------------------------------------------------------------------
 class LinuxCompilerGCC(UnixCompilerGCC):
