@@ -56,6 +56,7 @@ class ReplaceDirtInString:
         self.workdir = self.find( 'WorkDir' )
         self.python = self.find( 'PYTHON' )
         self.username = self.find( 'Username' )
+        self.svn_bin = self.find( 'SVN_BIN' )
         self.svn_version = svn_version
 
         self.txn_client_replacement = None
@@ -117,6 +118,11 @@ class ReplaceDirtInString:
             self.replacement_list.append(
                  (python_re,            '<PYTHON>') )
 
+        if self.svn_bin:
+            svn_bin_re  = LiteralCaseBlindSearch( self.svn_bin )
+            self.replacement_list.append(
+                (svn_bin_re,            '<SVN_BIN>') )
+
         if True:
             # must replace username after workdir
             username_spaces_re = re.compile( r'\b'+self.username+' * ' )
