@@ -1,6 +1,9 @@
+print( 'Info: test_01_set_get_tests start' )
 import sys
+print( 'Info: test_01_set_get_tests import pysvn' )
 import pysvn
 
+print( 'Info: test_01_set_get_tests pysvn.Client( %s )' % (sys.argv[1],) )
 c = pysvn.Client( sys.argv[1] )
 
 print( 'Info: Initial values' )
@@ -47,3 +50,7 @@ print( 'Info: get_default_password() => %r' % c.get_default_password() )
 print( 'Info: get_default_username() => %r' % c.get_default_username() )
 print( 'Info: get_interactive() => %r' % c.get_interactive() )
 print( 'Info: get_store_passwords() => %r' % c.get_store_passwords() )
+
+print( 'Info: test_01_set_get_tests dealloc Client()' )
+del c
+print( 'Info: test_01_set_get_tests done' )
